[![Build Status](https://travis-ci.com/RustyBower/sopel-cryptocurrency.svg?branch=master)](https://travis-ci.com/RustyBower/sopel-cryptocurrency)
[![Total alerts](https://img.shields.io/lgtm/alerts/g/RustyBower/sopel-cryptocurrency.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/RustyBower/sopel-cryptocurrency/alerts/)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/RustyBower/sopel-cryptocurrency.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/RustyBower/sopel-cryptocurrency/context:python)
[![Maintainability](https://api.codeclimate.com/v1/badges/3907c6471663c6ee88df/maintainability)](https://codeclimate.com/github/RustyBower/sopel-cryptocurrency/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/3907c6471663c6ee88df/test_coverage)](https://codeclimate.com/github/RustyBower/sopel-cryptocurrency/test_coverage)

# sopel-cryptocurrency
Cryptocurrency Module for Sopel

## Requirements
#### API Key
```
https://pro.coinmarketcap.com/
```

#### Python Requirements
```
arrow
requests
sopel
```

## Usage
```
.btc
BTC $7646.86 (-0.11%)⬇ (Last Updated: a minute ago)

.doge
DOGE $0.00236524 (0.14%)⬆ (Last Updated: a minute ago)

.eth
ETH $154.931 (-0.04%)⬇ (Last Updated: seconds ago)

.ltc
LTC $48.1955 (-0.31%)⬇ (Last Updated: seconds ago)
```
